diff --git a/doc/qtcreator.qdoc b/doc/qtcreator.qdoc
index 2994df2c699328a9cf8bcd5ec8579089979443ee..af4103cf4699e3f90d238b72ca5ce60cf10501e6 100644
--- a/doc/qtcreator.qdoc
+++ b/doc/qtcreator.qdoc
@@ -1941,7 +1941,7 @@
         \o  Mac OS 10.4 and later
     \endlist
 
-    \note Building the sources requires \bold{Qt 4.5.0} or later.
+    \note Building the sources requires \bold{Qt 4.6.0} or later.
 */
 
 
diff --git a/share/qtcreator/gdbmacros/gdbmacros.cpp b/share/qtcreator/gdbmacros/gdbmacros.cpp
index ecaee41ec3ac5bb0d663c64429c16ca2f9058bb7..11f83c65c907176fa7d800c769c5089181b52b10 100644
--- a/share/qtcreator/gdbmacros/gdbmacros.cpp
+++ b/share/qtcreator/gdbmacros/gdbmacros.cpp
@@ -633,7 +633,7 @@ QDumper &QDumper::put(const void *p)
     if (p) {
         // Pointer is 'long long' on WIN_64, only
         static const char *printFormat = sizeof(quintptr) == sizeof(long) ? "0x%lx" : "0x%llx";
-        pos += sprintf(outBuffer + pos, printFormat, reinterpret_cast<uintptr_t>(p));
+        pos += sprintf(outBuffer + pos, printFormat, reinterpret_cast<quintptr>(p));
     } else {
         pos += sprintf(outBuffer + pos, "<null>");
     }
@@ -1069,7 +1069,7 @@ static void qDumpQAbstractItem(QDumper &d)
        static const char *printFormat = sizeof(quintptr) == sizeof(long) ?
                                         "%d,%d,0x%lx,0x%lx" : "%d,%d,0x%llx,0x%llx";
        sscanf(d.templateParameters[0], printFormat, &mm->r, &mm->c,
-	      reinterpret_cast<uintptr_t*>(&mm->p), reinterpret_cast<uintptr_t*>(&mm->m));
+	      reinterpret_cast<quintptr*>(&mm->p), reinterpret_cast<quintptr*>(&mm->m));
     }
     const QAbstractItemModel *m = mi.model();
     const int rowCount = m->rowCount(mi);
diff --git a/share/qtcreator/translations/qtcreator_de.ts b/share/qtcreator/translations/qtcreator_de.ts
index 67f803de6e93c2ee811b257ea9e5810cb2fefccb..fa61bcbb885060c2a5c30d84fb275554fb356902 100644
--- a/share/qtcreator/translations/qtcreator_de.ts
+++ b/share/qtcreator/translations/qtcreator_de.ts
@@ -514,7 +514,7 @@
     <message>
         <location filename="../../../src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp" line="-133"/>
         <source>Qt Creator has detected an &lt;b&gt;in-source-build in %1&lt;/b&gt; which prevents shadow builds. Qt Creator will not allow you to change the build directory. If you want a shadow build, clean your source directory and re-open the project.</source>
-        <translation>Es wurde ein &lt;b&gt;Build im Quellverzeichnis&lt;/b&gt; festgestellt, der Shadow-Builds verhindert. Das Build-Verzeichnis kann nicht in Qt Creator geändert werden. Wenn Sie einen Shadow-Build wünschen, bereinigen Sie bitte das Quellverzeichnis und öffnen Sie das Projekt noch einmal.</translation>
+        <translation>Es wurde ein &lt;b&gt;Build im Quellverzeichnis %1&lt;/b&gt; festgestellt, der Shadow-Builds verhindert. Das Build-Verzeichnis kann nicht in Qt Creator geändert werden. Wenn Sie einen Shadow-Build wünschen, bereinigen Sie bitte das Quellverzeichnis und öffnen Sie das Projekt noch einmal.</translation>
     </message>
 </context>
 <context>
@@ -10396,7 +10396,7 @@ unter Versionsverwaltung (%2) gestellt werden?</translation>
     <message>
         <location line="+6"/>
         <source>The active build configuration builds a target that cannot be used by the active run configuration.</source>
-        <translation>Die aktive Build-Konfiguration erstellt ein Ziel, was von der aktive Ausführungskonfiguration nicht verwendet werden kann.</translation>
+        <translation>Die aktive Build-Konfiguration erstellt ein Ziel, das von der aktiven Ausführungskonfiguration nicht verwendet werden kann.</translation>
     </message>
     <message>
         <location line="+13"/>
diff --git a/share/qtcreator/translations/qtcreator_pl.ts b/share/qtcreator/translations/qtcreator_pl.ts
index 6a392a0e7195c71e70b80832137a86285be65692..327192d7a8dd55d26fbd369f3e952fc4472b04cd 100644
--- a/share/qtcreator/translations/qtcreator_pl.ts
+++ b/share/qtcreator/translations/qtcreator_pl.ts
@@ -2052,7 +2052,7 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+45"/>
+        <location line="+46"/>
         <source>New Project...</source>
         <translation>Nowy projekt...</translation>
     </message>
@@ -2524,7 +2524,7 @@ It also automatically sets the correct Qt version.</source>
     <message>
         <location line="+1"/>
         <source>You can fine tune the &lt;tt&gt;Find&lt;/tt&gt; function by selecting &amp;quot;Whole Words&amp;quot; or &amp;quot;Case Sensitive&amp;quot;. Simply click on the icons on the right end of the line edit.</source>
-        <translation>Możesz wyregulować działanie funkcji &lt;tt&gt;Znajdź&lt;/tt&gt; poprzez wybranie &amp;quot;Tylko całe słowa&amp;quot; lub &amp;quot;Uwzględniaj wielkość liter&amp;quot;.W tym celu naciśnij ikonę w prawym końcu pola edycyjnego.</translation>
+        <translation type="unfinished">Możesz wyregulować działanie funkcji &lt;tt&gt;Znajdź&lt;/tt&gt; poprzez wybranie &amp;quot;Tylko całe słowa&amp;quot; lub &amp;quot;Uwzględniaj wielkość liter&amp;quot;. W tym celu naciśnij ikonę w prawym końcu pola edycyjnego.</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -2589,8 +2589,12 @@ It also automatically sets the correct Qt version.</source>
     </message>
     <message>
         <location line="+2"/>
+        <source>In the editor, &lt;tt&gt;F2&lt;/tt&gt; follows symbol definition, &lt;tt&gt;Shift+F2&lt;/tt&gt; toggles declaration and definition while &lt;tt&gt;F4&lt;/tt&gt; toggles header file and source file.</source>
+        <translation>Naciśnięcie w edytorze &lt;tt&gt;F2&lt;/tt&gt; powoduje skok do definicji symbolu, &lt;tt&gt;Shift+F2&lt;/tt&gt; przełącza między deklaracją a definicją, zaś &lt;tt&gt;F4&lt;/tt&gt; przełącza między plikiem nagłówkowym a plikiem źródłowym.</translation>
+    </message>
+    <message>
         <source>In the editor, &lt;tt&gt;F2&lt;/tt&gt; toggles declaration and definition while &lt;tt&gt;F4&lt;/tt&gt; toggles header file and source file.</source>
-        <translation>Naciśnięcie w edytorze &lt;tt&gt;F2&lt;/tt&gt; przełącza między deklaracją a definicją, zaś &lt;tt&gt;F4&lt;/tt&gt; przełącza między plikiem nagłówkowym a plikiem źródłowym.</translation>
+        <translation type="obsolete">Naciśnięcie w edytorze &lt;tt&gt;F2&lt;/tt&gt; przełącza między deklaracją a definicją, zaś &lt;tt&gt;F4&lt;/tt&gt; przełącza między plikiem nagłówkowym a plikiem źródłowym.</translation>
     </message>
 </context>
 <context>
@@ -2715,13 +2719,13 @@ It also automatically sets the correct Qt version.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+47"/>
-        <location line="+65"/>
+        <location line="+23"/>
+        <location line="+115"/>
         <source>Default Qt Version (%1)</source>
         <translation>Domyślna wersja Qt (%1)</translation>
     </message>
     <message>
-        <location line="-61"/>
+        <location line="-111"/>
         <source>No Qt Version set</source>
         <translation>Nie ustawiono wersji Qt</translation>
     </message>
@@ -2827,6 +2831,11 @@ p, li { white-space: pre-wrap; }
         <source>Carbide Directory:</source>
         <translation>Katalog Carbide:</translation>
     </message>
+    <message>
+        <location/>
+        <source>CLS/GCCE Directory:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ShowBuildLog</name>
@@ -4861,7 +4870,7 @@ Czy chcesz je nadpisać?</translation>
     <message>
         <location line="+4"/>
         <source>Split Side by Side</source>
-        <translation type="unfinished"></translation>
+        <translation>Podziel sÄ…siadujÄ…co</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -4974,7 +4983,7 @@ Czy chcesz je nadpisać?</translation>
     <message>
         <location line="+92"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; You are changing a read-only file.</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Ostrzeżenie:&lt;/b&gt; Zmieniasz plik który jest tylko do odczytu.</translation>
     </message>
     <message>
         <location line="+15"/>
@@ -5004,7 +5013,7 @@ Czy chcesz je nadpisać?</translation>
     <message>
         <location line="+197"/>
         <source>You will lose your current changes if you proceed reverting %1.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Utracisz swoje bieżące zmiany</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -5102,11 +5111,6 @@ Czy chcesz je nadpisać?</translation>
         <source>Go Back</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="+0"/>
-        <source>Go Back</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location line="+2"/>
         <source>Go Forward</source>
@@ -7572,7 +7576,7 @@ Zwróć uwagę że spowoduje to usunięcie lokalnego pliku.</translation>
         <translation>Wczytywanie %1...</translation>
     </message>
     <message>
-        <location line="+39"/>
+        <location line="+44"/>
         <source>Running...</source>
         <translation>Uruchamianie...</translation>
     </message>
@@ -7603,7 +7607,7 @@ Zwróć uwagę że spowoduje to usunięcie lokalnego pliku.</translation>
         <translation>Uruchomienie programu zakończone niepowodzeniem: %1</translation>
     </message>
     <message>
-        <location line="+128"/>
+        <location line="+122"/>
         <source>Jumped. Stopped.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -7633,12 +7637,12 @@ Zwróć uwagę że spowoduje to usunięcie lokalnego pliku.</translation>
         <translation>Ładowanie %1...</translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+79"/>
         <source>Stopped at breakpoint.</source>
         <translation>Zatrzymano w pułapce.</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+9"/>
         <source>&lt;p&gt;The inferior stopped because it received a signal from the Operating System.&lt;p&gt;&lt;table&gt;&lt;tr&gt;&lt;td&gt;Signal name : &lt;/td&gt;&lt;td&gt;%1&lt;/td&gt;&lt;/tr&gt;&lt;tr&gt;&lt;td&gt;Signal meaning : &lt;/td&gt;&lt;td&gt;%2&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -7655,17 +7659,17 @@ Zwróć uwagę że spowoduje to usunięcie lokalnego pliku.</translation>
     </message>
     <message>
         <location line="+5"/>
-        <location line="+110"/>
+        <location line="+101"/>
         <source>Stopped.</source>
         <translation>Zatrzymano.</translation>
     </message>
     <message>
-        <location line="-108"/>
+        <location line="-99"/>
         <source>Stopped: &quot;%1&quot;</source>
         <translation>Zatrzymano: &quot;%1&quot;</translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+52"/>
         <source>The debugger you are using identifies itself as:</source>
         <translation>Debugger którego używasz identyfikuje się jako:</translation>
     </message>
@@ -7679,7 +7683,7 @@ Debugowanie najprawdopodobniej nie będzie działało poprawnie.
 Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
     </message>
     <message>
-        <location line="+257"/>
+        <location line="+260"/>
         <source>Continuing after temporary stop...</source>
         <translation>Kontynuowanie po tymczasowym zatrzymaniu...</translation>
     </message>
@@ -7729,13 +7733,13 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
         <translation type="unfinished">Nie można uruchomić &quot;%1&quot;: %2</translation>
     </message>
     <message>
-        <location line="+68"/>
+        <location line="+74"/>
         <source>&lt;unknown&gt;</source>
         <extracomment>End address of loaded module</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+37"/>
+        <location line="+45"/>
         <location line="+8"/>
         <source>Retrieving data for stack view...</source>
         <translation type="unfinished"></translation>
@@ -7851,7 +7855,7 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-2915"/>
+        <location line="-2932"/>
         <source>Execution Error</source>
         <translation type="unfinished"></translation>
     </message>
@@ -7862,7 +7866,7 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+990"/>
+        <location line="+1007"/>
         <source>Jumping out of bogus frame...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -7887,17 +7891,17 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+30"/>
         <source>Inferior start failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-2922"/>
+        <location line="-2938"/>
         <source>Inferior shutdown failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+2942"/>
+        <location line="+2958"/>
         <source>Adapter crashed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -7993,9 +7997,14 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
     </message>
     <message>
         <location line="+24"/>
+        <source>Connecting to TRK server adapter failed:
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Connecting to trk server adapter failed:
 </source>
-        <translation>Nie można połączyć się z adapterem serwera trk:
+        <translation type="obsolete">Nie można połączyć się z adapterem serwera trk:
 </translation>
     </message>
 </context>
@@ -8015,9 +8024,13 @@ Zaleca się użycie gdb wersji 6.7 lub późniejszej.</translation>
 <context>
     <name>Debugger::Internal::TrkOptionsPage</name>
     <message>
-        <location filename="../../../src/plugins/debugger/gdb/trkoptionspage.cpp" line="+43"/>
         <source>Symbian Trk</source>
-        <translation>Symbian Trk</translation>
+        <translation type="obsolete">Symbian Trk</translation>
+    </message>
+    <message>
+        <location filename="../../../src/plugins/debugger/gdb/trkoptionspage.cpp" line="+43"/>
+        <source>Symbian TRK</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -10948,7 +10961,7 @@ Rebuilding the project might help.</source>
 <context>
     <name>ProjectExplorer::Internal::BuildSettingsPanel</name>
     <message>
-        <location filename="../../../src/plugins/projectexplorer/buildsettingspropertiespage.cpp" line="+80"/>
+        <location filename="../../../src/plugins/projectexplorer/buildsettingspropertiespage.cpp" line="+81"/>
         <source>Build Settings</source>
         <translation>Ustawienia budowania</translation>
     </message>
@@ -10956,7 +10969,7 @@ Rebuilding the project might help.</source>
 <context>
     <name>ProjectExplorer::Internal::BuildSettingsWidget</name>
     <message>
-        <location line="+75"/>
+        <location line="+77"/>
         <source>Edit Build Configuration:</source>
         <translation>Zmodyfikuj konfiguracjÄ™ budowania:</translation>
     </message>
@@ -10971,7 +10984,7 @@ Rebuilding the project might help.</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location line="+32"/>
+        <location line="+49"/>
         <source>&amp;Clone Selected</source>
         <translation>S&amp;klonuj wybranÄ…</translation>
     </message>
@@ -10986,7 +10999,12 @@ Rebuilding the project might help.</source>
         <translation>Kroki procesu czyszczenia</translation>
     </message>
     <message>
-        <location line="+69"/>
+        <location line="+48"/>
+        <source>&lt;a href=&quot;#&quot;&gt;Make %1 active.&lt;/a&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Clone configuration</source>
         <translation>Sklonuj konfiguracjÄ™</translation>
     </message>
@@ -11446,7 +11464,7 @@ Reason: %2</source>
 <context>
     <name>ProjectExplorer::ProjectExplorerPlugin</name>
     <message>
-        <location filename="../../../src/plugins/projectexplorer/projectexplorer.cpp" line="+256"/>
+        <location filename="../../../src/plugins/projectexplorer/projectexplorer.cpp" line="+257"/>
         <source>Projects</source>
         <translation>Projekty</translation>
     </message>
@@ -11679,7 +11697,7 @@ Reason: %2</source>
         <translation>Nowy projekt</translation>
     </message>
     <message>
-        <location line="+867"/>
+        <location line="+900"/>
         <source>New File</source>
         <comment>Title of dialog</comment>
         <translation>Nowy plik</translation>
@@ -11768,6 +11786,49 @@ do systemu kontroli wersji (%2)?</translation>
         <translation>Nie można usunąć pliku %1.</translation>
     </message>
 </context>
+<context>
+    <name>ProjectExplorer::Internal::BuildConfigDialog</name>
+    <message>
+        <location line="+212"/>
+        <source>Change build configuration &amp;&amp; continue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Anuluj</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Continue anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Run configuration doesn&apos;t match build configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The active build configuration builds a target that cannot be used by the active run configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>This can happen if the active build configuration uses the wrong Qt version and/or tool chain for the active run configuration (e.g. running in Symbian emulator requires building with WINSCW tool chain).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Choose build configuration:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>No valid build configuration found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ProjectExplorer::Internal::ProjectExplorerSettingsPage</name>
     <message>
@@ -11929,6 +11990,11 @@ do systemu kontroli wersji (%2)?</translation>
         <source>Remove</source>
         <translation>Usuń</translation>
     </message>
+    <message>
+        <location line="+133"/>
+        <source>&lt;a href=&quot;#&quot;&gt;Make %1 active.&lt;/a&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProjectExplorer::Internal::SessionFile</name>
@@ -12380,12 +12446,12 @@ do systemu kontroli wersji (%2)?</translation>
 <context>
     <name>Qt4ProjectManager::MakeStepConfigWidget</name>
     <message>
-        <location line="+54"/>
+        <location line="+57"/>
         <source>Override %1:</source>
         <translation>Nadpisanie %1:</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+18"/>
         <source>&lt;b&gt;Make Step:&lt;/b&gt; %1 not found in the environment.</source>
         <translation>&lt;b&gt;Krok Make:&lt;/b&gt; Nie odnaleziono %1 w środowisku.</translation>
     </message>
@@ -12486,7 +12552,7 @@ do systemu kontroli wersji (%2)?</translation>
 <context>
     <name>Qt4ProjectManager::Internal::S60DeviceRunConfiguration</name>
     <message>
-        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60devicerunconfiguration.cpp" line="+81"/>
+        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60devicerunconfiguration.cpp" line="+84"/>
         <source>%1 on Symbian Device</source>
         <translation>%1 na urzÄ…dzeniu Symbian</translation>
     </message>
@@ -12496,7 +12562,7 @@ do systemu kontroli wersji (%2)?</translation>
         <translation>Konfiguracja procesu uruchamiania urzÄ…dzenia QtS60</translation>
     </message>
     <message>
-        <location line="+197"/>
+        <location line="+205"/>
         <source>Could not parse %1. The QtS60 Device run configuration %2 can not be started.</source>
         <translation>Nie można przetworzyć %1. Nie można rozpocząć konfiguracji procesu uruchamiania %2 dla urządzenia QtS60.</translation>
     </message>
@@ -12504,7 +12570,7 @@ do systemu kontroli wersji (%2)?</translation>
 <context>
     <name>Qt4ProjectManager::Internal::S60DeviceRunConfigurationWidget</name>
     <message>
-        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60devicerunconfigurationwidget.cpp" line="+73"/>
+        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60devicerunconfigurationwidget.cpp" line="+75"/>
         <source>Device:</source>
         <translation>UrzÄ…dzenie:</translation>
     </message>
@@ -12554,7 +12620,7 @@ do systemu kontroli wersji (%2)?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+125"/>
+        <location line="+126"/>
         <source>&lt;No Device&gt;</source>
         <extracomment>Summary text of S60 device run configuration</extracomment>
         <translation>&lt;Brak urzÄ…dzenia&gt;</translation>
@@ -12575,15 +12641,10 @@ do systemu kontroli wersji (%2)?</translation>
         <translation>Podsumowanie: Uruchomiono na &quot;%1&quot; %2</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+50"/>
         <source>Connecting...</source>
         <translation>Łączenie...</translation>
     </message>
-    <message>
-        <location line="+53"/>
-        <source>A timeout occurred while querying the device. Check whether Trk is running</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Qt4ProjectManager::Internal::S60DeviceRunConfigurationFactory</name>
@@ -12597,6 +12658,11 @@ do systemu kontroli wersji (%2)?</translation>
     <name>Qt4ProjectManager::Internal::S60DeviceRunControlBase</name>
     <message>
         <location line="+83"/>
+        <source>There is no device plugged in.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>Creating %1.sisx ...</source>
         <translation>Tworzenie %1.sisx ...</translation>
     </message>
@@ -12612,12 +12678,12 @@ do systemu kontroli wersji (%2)?</translation>
     </message>
     <message>
         <location line="+12"/>
-        <location line="+76"/>
+        <location line="+90"/>
         <source>%1 %2</source>
         <translation>%1 %2</translation>
     </message>
     <message>
-        <location line="-41"/>
+        <location line="-42"/>
         <source>Could not read template package file &apos;%1&apos;</source>
         <translation>Nie można odczytać pliku z pakietem szablonów &quot;%1&quot;</translation>
     </message>
@@ -12628,26 +12694,31 @@ do systemu kontroli wersji (%2)?</translation>
     </message>
     <message>
         <location line="+16"/>
-        <location line="+28"/>
+        <location line="+29"/>
         <source>An error occurred while creating the package.</source>
         <translation>Wystąpił błąd podczas tworzenia pakietu.</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Package: %1
 Deploying application to &apos;%2&apos;...</source>
         <translation>Pakiet: %1
 Umieszczanie aplikacji w &quot;%2&quot;...</translation>
     </message>
     <message>
-        <location line="+23"/>
         <source>Could not connect to phone on port &apos;%1&apos;: %2
 Check if the phone is connected and the TRK application is running.</source>
-        <translation>Nie można nawiązać połączenia z telefonem na porcie &quot;%1&quot;: %2
+        <translation type="obsolete">Nie można nawiązać połączenia z telefonem na porcie &quot;%1&quot;: %2
 Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+21"/>
+        <source>Could not connect to phone on port &apos;%1&apos;: %2
+Check if the phone is connected and App TRK is running.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+9"/>
         <source>Could not create file %1 on device: %2</source>
         <translation>Nie można utworzyć pliku %1 na urządzeniu: %2</translation>
     </message>
@@ -12687,7 +12758,22 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <translation>Nie można zainstalować z pakietu %1 na urządzeniu: %2</translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+12"/>
+        <source>Waiting for App TRK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Please start App TRK on %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+22"/>
+        <source>Canceled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+10"/>
         <source>Failed to start %1.</source>
         <translation>Nie można uruchomić %1.</translation>
     </message>
@@ -12705,7 +12791,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
 <context>
     <name>Qt4ProjectManager::Internal::S60DeviceRunControl</name>
     <message>
-        <location line="+37"/>
+        <location line="+38"/>
         <source>Finished.</source>
         <translation>Zakończono.</translation>
     </message>
@@ -12816,7 +12902,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
 <context>
     <name>Qt4ProjectManager::Internal::S60Manager</name>
     <message>
-        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60manager.cpp" line="+111"/>
+        <location filename="../../../src/plugins/qt4projectmanager/qt-s60/s60manager.cpp" line="+113"/>
         <source>Run in Emulator</source>
         <translation>Uruchom w emulatorze</translation>
     </message>
@@ -12929,7 +13015,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <translation>Używając wersji &quot;%1&quot;</translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+26"/>
         <source>New configuration</source>
         <translation>Nowa konfiguracja</translation>
     </message>
@@ -12939,7 +13025,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <translation>Nazwa nowej konfiguracji:</translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="+7"/>
         <source>%1 Debug</source>
         <translation>%1 Debug</translation>
     </message>
@@ -13279,6 +13365,11 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <source>Select S60 SDK Root</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>Select the CSL Arm Toolchain (GCCE) Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+11"/>
         <source>Auto-detected</source>
@@ -13290,7 +13381,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <translation>Ustawione ręcznie</translation>
     </message>
     <message>
-        <location line="+142"/>
+        <location line="+144"/>
         <source>Building helpers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -13301,7 +13392,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+124"/>
         <source>The Qt Version identified by %1 is not installed. Run make install</source>
         <translation>Wersja Qt identyfikowana przez %1 nie jest zainstalowana. Uruchom &quot;make install&quot;</translation>
     </message>
@@ -13319,7 +13410,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
 <context>
     <name>Qt4ProjectManager::QtVersionManager</name>
     <message>
-        <location filename="../../../src/plugins/qt4projectmanager/qtversionmanager.cpp" line="+332"/>
+        <location filename="../../../src/plugins/qt4projectmanager/qtversionmanager.cpp" line="+351"/>
         <source>&lt;not found&gt;</source>
         <translation>&lt;nie znaleziony&gt;</translation>
     </message>
@@ -13373,7 +13464,7 @@ Sprawdź czy telefon jest podłączony i czy aplikacja TRK jest uruchomiona.</tr
 <context>
     <name>QApplication</name>
     <message>
-        <location line="+862"/>
+        <location line="+872"/>
         <source>The Qt Version has no toolchain.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -16007,13 +16098,13 @@ aktywny tylko po wpisaniu przedrostka</translation>
     </message>
     <message>
         <location filename="../../../src/plugins/qmleditor/parser/qmljsparser.cpp" line="+1752"/>
-        <source>Unexpected token `%1&apos;</source>
+        <source>Unexpected token &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location line="+28"/>
         <location line="+23"/>
-        <source>Expected token `%1&apos;</source>
+        <source>Expected token &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -16031,12 +16122,12 @@ aktywny tylko po wpisaniu przedrostka</translation>
     </message>
     <message>
         <location line="+16"/>
-        <source>Waiting for TRK</source>
+        <source>Waiting for App TRK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location line="+1"/>
-        <source>Waiting for TRK to start on %1...</source>
+        <source>Waiting for App TRK to start on %1...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
diff --git a/src/plugins/cvs/cvseditor.h b/src/plugins/cvs/cvseditor.h
index a3d38bfff4b1c02cf177a864c8d6a331b8fe856b..a9bb40eaf5008042db1e7e382b1a42b210139016 100644
--- a/src/plugins/cvs/cvseditor.h
+++ b/src/plugins/cvs/cvseditor.h
@@ -59,7 +59,8 @@ private:
     virtual VCSBase::BaseAnnotationHighlighter *createAnnotationHighlighter(const QSet<QString> &changes) const;
     virtual QString fileNameFromDiffSpecification(const QTextBlock &diffFileName) const;
 
-    const QRegExp m_revisionPattern;
+    const QRegExp m_revisionAnnotationPattern;
+    const QRegExp m_revisionLogPattern;
     QString m_diffBaseDir;
 };
 
diff --git a/src/plugins/debugger/gdb/gdbengine.cpp b/src/plugins/debugger/gdb/gdbengine.cpp
index 44453ff47cee2b6af1428be5f037bfb7555a06bd..fcaac3ab3f9bee494db697be217ba7e77d8f2620 100644
--- a/src/plugins/debugger/gdb/gdbengine.cpp
+++ b/src/plugins/debugger/gdb/gdbengine.cpp
@@ -258,6 +258,7 @@ void GdbEngine::initializeVariables()
     m_gdbBuildVersion = -1;
     m_isMacGdb = false;
     m_isSynchroneous = false;
+    m_registerNamesListed = false;
 
     m_fullToShortName.clear();
     m_shortToFullName.clear();
@@ -2430,6 +2431,11 @@ void GdbEngine::handleStackListThreads(const GdbResponse &response)
 
 void GdbEngine::reloadRegisters()
 {
+    if (!m_registerNamesListed) {
+        postCommand(_("-data-list-register-names"), CB(handleRegisterListNames));
+        m_registerNamesListed = true;
+    }
+
     if (m_gdbAdapter->isTrkAdapter()) {
         // FIXME: remove that special case. This is only to prevent
         // gdb from asking for the values of the fixed point registers
@@ -2458,8 +2464,10 @@ void GdbEngine::setRegisterValue(int nr, const QString &value)
 
 void GdbEngine::handleRegisterListNames(const GdbResponse &response)
 {
-    if (response.resultClass != GdbResultDone)
+    if (response.resultClass != GdbResultDone) {
+        m_registerNamesListed = false;
         return;
+    }
 
     QList<Register> registers;
     foreach (const GdbMi &item, response.data.findChild("register-names").children())
@@ -4204,7 +4212,6 @@ bool GdbEngine::startGdb(const QStringList &args, const QString &gdb, const QStr
 
     postCommand(_("set breakpoint pending on"));
     postCommand(_("set print elements 10000"));
-    postCommand(_("-data-list-register-names"), CB(handleRegisterListNames));
 
     //postCommand(_("set substitute-path /var/tmp/qt-x11-src-4.5.0 "
     //    "/home/sandbox/qtsdk-2009.01/qt"));
diff --git a/src/plugins/debugger/gdb/gdbengine.h b/src/plugins/debugger/gdb/gdbengine.h
index c9e20eae299685f307bce861e251cec626db3cc7..1229cc17d9d759a862a4f33d6cbe3e7592a4f09c 100644
--- a/src/plugins/debugger/gdb/gdbengine.h
+++ b/src/plugins/debugger/gdb/gdbengine.h
@@ -121,6 +121,7 @@ private: ////////// General State //////////
 
     DebuggerStartParametersPtr m_startParameters;
     QSharedPointer<TrkOptions> m_trkOptions;
+    bool m_registerNamesListed;
 
 private: ////////// Gdb Process Management //////////
 
@@ -461,7 +462,6 @@ private: ////////// Convenience Functions //////////
     void showMessageBox(int icon, const QString &title, const QString &text);
     void debugMessage(const QString &msg);
     QMainWindow *mainWindow() const;
-
 };
 
 } // namespace Internal
diff --git a/src/plugins/debugger/stackhandler.cpp b/src/plugins/debugger/stackhandler.cpp
index ec47a02b1591252e8befd053ee784b9e0851d7a7..fa6b972e555d87356cb49a015875f7988c48923a 100644
--- a/src/plugins/debugger/stackhandler.cpp
+++ b/src/plugins/debugger/stackhandler.cpp
@@ -36,6 +36,7 @@
 #include <QtCore/QAbstractTableModel>
 #include <QtCore/QDebug>
 #include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 namespace Debugger {
 namespace Internal {
@@ -79,7 +80,7 @@ QString StackFrame::toToolTip() const
     str << "<html><body><table>"
         << "<tr><td>" << StackHandler::tr("Address:") << "</td><td>" <<  address << "</td></tr>"
         << "<tr><td>" << StackHandler::tr("Function:") << "</td><td>" << function << "</td></tr>"
-        << "<tr><td>" << StackHandler::tr("File:") << "</td><td>" << file << "</td></tr>"
+        << "<tr><td>" << StackHandler::tr("File:") << "</td><td>" << QDir::toNativeSeparators(file) << "</td></tr>"
         << "<tr><td>" << StackHandler::tr("Line:") << "</td><td>" << line << "</td></tr>"
         << "<tr><td>" << StackHandler::tr("From:") << "</td><td>" << from << "</td></tr>"
         << "<tr><td>" << StackHandler::tr("To:") << "</td><td>" << to << "</td></tr>"
diff --git a/src/plugins/qt4projectmanager/qmakestep.cpp b/src/plugins/qt4projectmanager/qmakestep.cpp
index f7953367c418ddd2fcb1ee662f8e62a32b1ac0b1..aae920c7fb61753cd792faf8e15a0bbe41f7df22 100644
--- a/src/plugins/qt4projectmanager/qmakestep.cpp
+++ b/src/plugins/qt4projectmanager/qmakestep.cpp
@@ -214,6 +214,8 @@ QMakeStepConfigWidget::QMakeStepConfigWidget(QMakeStep *step)
     connect(m_ui.buildConfigurationComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(buildConfigurationChanged()));
     connect(step, SIGNAL(changed()),
             this, SLOT(update()));
+    connect(step->project(), SIGNAL(qtVersionChanged(ProjectExplorer::BuildConfiguration *)),
+            this, SLOT(qtVersionChanged(ProjectExplorer::BuildConfiguration *)));
 }
 
 QString QMakeStepConfigWidget::summaryText() const
@@ -221,6 +223,14 @@ QString QMakeStepConfigWidget::summaryText() const
     return m_summaryText;
 }
 
+void QMakeStepConfigWidget::qtVersionChanged(ProjectExplorer::BuildConfiguration *bc)
+{
+    if (bc && bc->name() == m_buildConfiguration) {
+        updateTitleLabel();
+        updateEffectiveQMakeCall();
+    }
+}
+
 void QMakeStepConfigWidget::updateTitleLabel()
 {
     Qt4Project *qt4project = qobject_cast<Qt4Project *>(m_step->project());
diff --git a/src/plugins/qt4projectmanager/qmakestep.h b/src/plugins/qt4projectmanager/qmakestep.h
index 6588fa41bf6a387663e1a145a94513a8423b8829..d23d471636e28ab4bc0f9bf204824f8eeedd9e86 100644
--- a/src/plugins/qt4projectmanager/qmakestep.h
+++ b/src/plugins/qt4projectmanager/qmakestep.h
@@ -107,6 +107,7 @@ private slots:
     void qmakeArgumentsLineEditTextEdited();
     void buildConfigurationChanged();
     void update();
+    void qtVersionChanged(ProjectExplorer::BuildConfiguration *bc);
 private:
     void updateTitleLabel();
     void updateEffectiveQMakeCall();
diff --git a/src/plugins/qt4projectmanager/qt4project.cpp b/src/plugins/qt4projectmanager/qt4project.cpp
index dd7a37a48224fc9b8602efa8b6258f84bf4206fd..e75cb795ecf6047941d9e82de987de76dfd9ee5e 100644
--- a/src/plugins/qt4projectmanager/qt4project.cpp
+++ b/src/plugins/qt4projectmanager/qt4project.cpp
@@ -973,6 +973,7 @@ int Qt4Project::qtVersionId(BuildConfiguration *configuration) const
 void Qt4Project::setQtVersion(BuildConfiguration *configuration, int id)
 {
     configuration->setValue(KEY_QT_VERSION_ID, id);
+    emit qtVersionChanged(configuration);
     updateActiveRunConfiguration();
 }
 
diff --git a/src/plugins/qt4projectmanager/qt4project.h b/src/plugins/qt4projectmanager/qt4project.h
index 89083369b07b25295ed905f4ec5b525e58ab3a3b..0853723192afd60528d4d81203a949a9b59948bc 100644
--- a/src/plugins/qt4projectmanager/qt4project.h
+++ b/src/plugins/qt4projectmanager/qt4project.h
@@ -238,6 +238,7 @@ public:
     static QStringList removeSpecFromArgumentList(const QStringList &old);
 signals:
     void targetInformationChanged();
+    void qtVersionChanged(ProjectExplorer::BuildConfiguration *);
 
 public slots:
     void update();
diff --git a/src/plugins/vcsbase/vcsbasesettingspage.ui b/src/plugins/vcsbase/vcsbasesettingspage.ui
index 78a1326291cde949836eae4a2dd39daa7e770f11..a535a107069f547ad6bb7ec070151d3d6c33d9c4 100644
--- a/src/plugins/vcsbase/vcsbasesettingspage.ui
+++ b/src/plugins/vcsbase/vcsbasesettingspage.ui
@@ -65,6 +65,9 @@
         </item>
         <item>
          <layout class="QFormLayout" name="formLayout">
+          <property name="rowWrapPolicy">
+           <enum>QFormLayout::WrapLongRows</enum>
+          </property>
           <item row="0" column="0">
            <widget class="QLabel" name="submitMessageCheckScriptLabel">
             <property name="toolTip">
@@ -109,19 +112,6 @@ name &lt;email&gt; alias &lt;email&gt;</string>
         </item>
        </layout>
       </item>
-      <item>
-       <spacer name="horizontalSpacer">
-        <property name="orientation">
-         <enum>Qt::Horizontal</enum>
-        </property>
-        <property name="sizeHint" stdset="0">
-         <size>
-          <width>40</width>
-          <height>20</height>
-         </size>
-        </property>
-       </spacer>
-      </item>
      </layout>
     </widget>
    </item>
diff --git a/src/shared/trk/launcher.cpp b/src/shared/trk/launcher.cpp
index a554269f0ef429fa47a90b8ad2e0ed6a16fd4f2d..b9b5f04a1595422431992b1cbc5ebf440cebcc8c 100644
--- a/src/shared/trk/launcher.cpp
+++ b/src/shared/trk/launcher.cpp
@@ -201,7 +201,7 @@ bool Launcher::startServer(QString *errorMessage)
     }
     setState(Connecting);
     // Set up the temporary 'waiting' state if we do not get immediate connection
-    QTimer::singleShot(200, this, SLOT(slotWaitingForTrk()));
+    QTimer::singleShot(1000, this, SLOT(slotWaitingForTrk()));
     d->m_device->sendTrkInitialPing();
     d->m_device->sendTrkMessage(TrkDisconnect); // Disconnect, as trk might be still connected
     d->m_device->sendTrkMessage(TrkSupported, TrkCallback(this, &Launcher::handleSupportMask));
diff --git a/src/shared/trk/trkutils.cpp b/src/shared/trk/trkutils.cpp
index 4b63cad0343007ea260a671bb4e917dd0924942e..458390d88936ffb9baf1de800318d76cc40902fd 100644
--- a/src/shared/trk/trkutils.cpp
+++ b/src/shared/trk/trkutils.cpp
@@ -30,6 +30,7 @@
 #include "trkutils.h"
 #include <ctype.h>
 
+#include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
 
 #define logMessage(s)  do { qDebug() << "TRKCLIENT: " << s; } while (0)
@@ -70,38 +71,61 @@ void Session::reset()
     trkAppVersion.reset();
 }
 
-inline void formatCpu(QTextStream &str,int major, int minor)
+QString formatCpu(int major, int minor)
 {
-    str << "CPU: v" << major << '.' << minor;
+    //: CPU description of an S60 device
+    //: %1 major verison, %2 minor version
+    //: %3 real name of major verison, %4 real name of minor version
+    const QString str = QCoreApplication::translate("trk::Session", "CPU: v%1.%2%3%4");
+    QString majorStr;
+    QString minorStr;
     switch (major) {
     case 0x04:
-        str << " ARM";
+        majorStr = " ARM";
         break;
     }
     switch (minor) {
     case 0x00:
-        str << " 920T";
+        minorStr = " 920T";
         break;
     }
+    return str.arg(major).arg(minor).arg(majorStr).arg(minorStr);
  }
 
+QString formatTrkVersion(const TrkAppVersion &version)
+{
+    QString str = QCoreApplication::translate("trk::Session",
+                                              "App TRK: v%1.%2 TRK protocol: v%3.%4");
+    str = str.arg(version.trkMajor).arg(version.trkMinor);
+    return str.arg(version.protocolMajor).arg(version.protocolMinor);
+}
+
 QString Session::deviceDescription(unsigned verbose) const
 {
-    QString msg;
-    if (cpuMajor) {
-        QTextStream str(&msg);
-        formatCpu(str, cpuMajor, cpuMinor);
-        str << ", "  << (bigEndian ? "big endian" : "little endian");
-        if (verbose) {
-            if (defaultTypeSize)
-                str << ", type size: " << defaultTypeSize;
-            if (fpTypeSize)
-                str << ", float size: " << fpTypeSize;
-        }
-        str << ", App TRK: v" << trkAppVersion.trkMajor << '.' << trkAppVersion.trkMinor
-            << " TRK protocol: v" << trkAppVersion.protocolMajor << '.' << trkAppVersion.protocolMinor;
-    }
-    return msg;
+    if (!cpuMajor)
+        return QString();
+
+    //: s60description
+    //: description of an S60 device
+    //: %1 CPU description, %2 endianness
+    //: %3 default type size (if any), %4 float size (if any)
+    //: %5 TRK version
+    QString msg = QCoreApplication::translate("trk::Session", "%1, %2%3%4, %5");
+    QString endianness = bigEndian
+                         ? QCoreApplication::translate("trk::Session", "big endian")
+                         : QCoreApplication::translate("trk::Session", "little endian");
+    msg = msg.arg(formatCpu(cpuMajor, cpuMinor)).arg(endianness);
+    //: The separator in a list of strings
+    QString defaultTypeSizeStr;
+    QString fpTypeSizeStr;
+    if (verbose && defaultTypeSize)
+        //: will be inserted into s60description
+        defaultTypeSizeStr = QCoreApplication::translate("trk::Session", ", type size: %1").arg(defaultTypeSize);
+    if (verbose && fpTypeSize)
+        //: will be inserted into s60description
+        fpTypeSizeStr = QCoreApplication::translate("trk::Session", ", float size: %1").arg(fpTypeSize);
+    msg = msg.arg(defaultTypeSizeStr).arg(fpTypeSizeStr);
+    return msg.arg(formatTrkVersion(trkAppVersion));
 }
diff --git a/src/plugins/cvs/cvseditor.cpp b/src/plugins/cvs/cvseditor.cpp
index 38c1363aa60d3ae211a2f1a734949c431ec1cb8a..03f81adb59f1ce0b5acbe333314cf82970ddf600 100644
--- a/src/plugins/cvs/cvseditor.cpp
+++ b/src/plugins/cvs/cvseditor.cpp
@@ -48,9 +48,11 @@ namespace Internal {
 CVSEditor::CVSEditor(const VCSBase::VCSBaseEditorParameters *type,
                                    QWidget *parent) :
     VCSBase::VCSBaseEditor(type, parent),
-    m_revisionPattern(QLatin1String(CVS_REVISION_AT_START_PATTERN".*$"))
+    m_revisionAnnotationPattern(QLatin1String(CVS_REVISION_AT_START_PATTERN".*$")),
+    m_revisionLogPattern(QLatin1String("^revision  *("CVS_REVISION_PATTERN")$"))
 {
-    QTC_ASSERT(m_revisionPattern.isValid(), return);
+    QTC_ASSERT(m_revisionAnnotationPattern.isValid(), return);
+    QTC_ASSERT(m_revisionLogPattern.isValid(), return);
 }
 
 QSet<QString> CVSEditor::annotationChanges() const
@@ -79,16 +81,31 @@ QSet<QString> CVSEditor::annotationChanges() const
 
 QString CVSEditor::changeUnderCursor(const QTextCursor &c) const
 {
-
-    // Check for a revision number at the beginning of the line.
-    // Note that "cursor.select(QTextCursor::WordUnderCursor)" will
-    // only select the part up until the dot.
-    // Check if we are at the beginning of a line within a reasonable offset.
-    const QTextBlock block = c.block();
-    if (c.atBlockStart() || (c.position() - block.position() < 3)) {
-        const QString line = block.text();
-        if (m_revisionPattern.exactMatch(line))
-            return m_revisionPattern.cap(1);
+    // Try to match "1.1" strictly:
+    // 1) Annotation: Check for a revision number at the beginning of the line.
+    //    Note that "cursor.select(QTextCursor::WordUnderCursor)" will
+    //    only select the part up until the dot.
+    //    Check if we are at the beginning of a line within a reasonable offset.
+    // 2) Log: check for lines like "revision 1.1", cursor past "revision"
+    switch (contentType()) {
+    case VCSBase::RegularCommandOutput:
+    case VCSBase::DiffOutput:
+        break;
+    case VCSBase::AnnotateOutput: {
+            const QTextBlock block = c.block();
+            if (c.atBlockStart() || (c.position() - block.position() < 3)) {
+                const QString line = block.text();
+                if (m_revisionAnnotationPattern.exactMatch(line))
+                    return m_revisionAnnotationPattern.cap(1);
+            }
+        }
+        break;
+    case VCSBase::LogOutput: {
+            const QTextBlock block = c.block();
+            if (c.position() - block.position() > 8 && m_revisionLogPattern.exactMatch(block.text()))
+                return m_revisionLogPattern.cap(1);
+        }
+        break;
     }
     return QString();
 }